# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.2.0] - 2025-04-23

### Added

- Added `--version` option.
- Added `--help` option.

### Fixed

- Fixed the time displays.

## [0.1.2] - 2024-12-04

### Fixed

- Fixed crash at startup.

## [0.1.1] - 2024-11-01

### Fixed

- Fixed FontNotFound error.

## [0.1.0] - 2024-11-01

### Added

- Added a clock with the current local time.
- Added stopwatch.

[0.2.0]: https://github.com/sou-san/segmock/compare/v0.1.2...v0.2.0
[0.1.2]: https://github.com/sou-san/segmock/compare/v0.1.1...v0.1.2
[0.1.1]: https://github.com/sou-san/segmock/compare/v0.1.0...v0.1.1
[0.1.0]: https://github.com/sou-san/segmock/releases/tag/v0.1.0
